# Upstream source information.
%global upstream_owner    AdaCore
%global upstream_name     gprconfig_kb
%global upstream_version  24.0.0
%global upstream_gittag   v%{upstream_version}

Name:			gprconfig-kb
Version:		%{upstream_version}
Release:		1%{?dist}
Summary:		GNAT project configuration knowledge base
BuildArch:		noarch
License:        GPL-3.0-or-later WITH GCC-exception-3.1
URL:            https://github.com/%{upstream_owner}/%{upstream_name}
Source0:        %{url}/archive/%{upstream_gittag}/%{upstream_name}-%{upstream_version}.tar.gz

%if 0%{?fedora}
# [Fedora specific]
Source1:        fedora_arches.xml
Source2:        fedora_ar.xml
%else

# [Mageia specific]
Source3:		mageia_arches.xml
Source4:		mageia_ar.xml
%endif

# [specific to recent GCC] Make detection of GCC compilers independent of locale.
Patch1:         %{name}-improve-detection-of-gcc.patch
# Our guess at why Adacore don't do this is that they might want to support old
# versions of GCC that lack -dumpfullversion.

# [Unix-specific] Make detection of GNU ld independent of locale.
Patch2:         %{name}-improve-detection-of-gnu-ld.patch
# Use of env makes this patch specific to Unix-like systems.

# [specific to recent Clang] Make detection of Clang compilers independent of locale.
Patch3:         %{name}-improve-detection-of-clang.patch
# Our guess at why Adacore don't do this is that they might want to support old
# versions of Clang where -dumpversion returns a hardcoded fake version number.

# The contents of this package are split off from the gprbuild package.
Conflicts:      gprbuild <= 2020

%description
The GNAT project configuration knowledge base is used for configuring
GNAT project toolchains.

%prep
%autosetup -n %{upstream_name}-%{upstream_version} -p1

%build
%{nil}

%install
%global inst install --mode=u=rw,go=r,a-s --preserve-timestamps

mkdir --parents %{buildroot}%{_datadir}/gprconfig
%{inst} --target-directory=%{buildroot}%{_datadir}/gprconfig db/gprconfig.xsd
%{inst} --target-directory=%{buildroot}%{_datadir}/gprconfig db/*.xml
%{inst} --target-directory=%{buildroot}%{_datadir}/gprconfig db/*.ent
%if 0%{?fedora}
%{inst} --target-directory=%{buildroot}%{_datadir}/gprconfig %{SOURCE1} %{SOURCE2}
%else
%{inst} --target-directory=%{buildroot}%{_datadir}/gprconfig %{SOURCE3} %{SOURCE4}
%endif

%files
%license COPYING3 COPYING.RUNTIME
%doc README*
%{_datadir}/gprconfig
